package org.dromara.ems.base.mapper;

import org.dromara.ems.base.domain.EmsBaseSharePrice;

import java.util.List;

/**
 * 分时电价维护Mapper接口
 *
 * @author Yinq
 * @date 2024-06-11
 */
public interface EmsBaseSharePriceMapper {
    /**
     * 查询分时电价维护
     *
     * @param objId 分时电价维护主键
     * @return 分时电价维护
     */
    public EmsBaseSharePrice selectEmsBaseSharePriceByObjId(Long objId);

    /**
     * 查询分时电价维护列表
     *
     * @param emsBaseSharePrice 分时电价维护
     * @return 分时电价维护集合
     */
    public List<EmsBaseSharePrice> selectEmsBaseSharePriceList(EmsBaseSharePrice emsBaseSharePrice);

    /**
     * 新增分时电价维护
     *
     * @param emsBaseSharePrice 分时电价维护
     * @return 结果
     */
    public int insertEmsBaseSharePrice(EmsBaseSharePrice emsBaseSharePrice);

    /**
     * 修改分时电价维护
     *
     * @param emsBaseSharePrice 分时电价维护
     * @return 结果
     */
    public int updateEmsBaseSharePrice(EmsBaseSharePrice emsBaseSharePrice);

    /**
     * 删除分时电价维护
     *
     * @param objId 分时电价维护主键
     * @return 结果
     */
    public int deleteEmsBaseSharePriceByObjId(Long objId);

    /**
     * 批量删除分时电价维护
     *
     * @param objIds 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteEmsBaseSharePriceByObjIds(Long[] objIds);
}
